@@ -21,7 +21,7 @@ extends 'HPC::Runner';
 extends 'HPC::Runner::Slurm';
 with 'MooseX::SimpleConfig';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 # For pretty man pages!
 $ENV{TERM}='xterm-256color';
@@ -52,15 +52,19 @@ Same as the partition in HPC::Runner::Slurm
 
 has 'queue' => (
     is => 'rw',
-    isa => 'Str',
-    required => 1,
+    isa => 'Str|Undef',
+    required => 0,
     #default => 'adserial',
-    default => q(),
+    #default => '',
     documentation => q{PBS queue for job submission. Defaults is none, pbs decides.},
     predicate => 'has_queue',
     clearer => 'clear_queue',
 );
 
+has '+partition' =>(
+    isa => 'Str | Undef',
+);
+
 =head2 walltime
 
 Define PBS walltime
