@@ -13,9 +13,12 @@
 
 package Main;
 
+use Carp::Always;
 use Moose;
+use namespace::autoclean;
 extends 'HPC::Runner::PBS';
 
 Main->new_with_options->run;
 
+__PACKAGE__->meta->make_immutable;
 1;
